==> victory-0.3.0.tgz: package/ROADMAP.md <==
# Victory Release Roadmap

Release schedule for the Victory ecosystem. Subject to change and reprioritization.

## Feature requests

We'd love :heart: to hear what you think we should build! First, please [search for an existing issue](https://github.com/FormidableLabs/victory/issues) with your feature request, and `+1` it. If nobody has suggested it yet, please [create a new issue](https://github.com/FormidableLabs/victory/issues/new?labels=enhancement)!

## Releases

### [Alpha](https://github.com/FormidableLabs/victory/milestones/Alpha)

Released: December 2015 ([`v0.1.0`](https://github.com/FormidableLabs/victory/releases/tag/v0.1.0))

- [victory-animation](https://github.com/FormidableLabs/victory-animation)
- [victory-axis](https://github.com/FormidableLabs/victory-axis)
- [victory-bar](https://github.com/FormidableLabs/victory-bar)
- [victory-chart](https://github.com/FormidableLabs/victory-chart)
- [victory-label](https://github.com/FormidableLabs/victory-label)
- [victory-line](https://github.com/FormidableLabs/victory-line)
- [victory-pie](https://github.com/FormidableLabs/victory-pie)
- [victory-scatter](https://github.com/FormidableLabs/victory-scatter)
- Basic code coverage across all Victory components (#37)

### [Alpha 2](https://github.com/FormidableLabs/victory/milestones/Alpha%202)

Expected release: January 2016

- [victory-tooltip](https://github.com/FormidableLabs/victory/issues/83)
- [Support data accessor functions](https://github.com/FormidableLabs/victory/issues/84)
- Inverted axis support
- [Horizontal bar chart support](https://github.com/FormidableLabs/victory/issues/36)
- General interactivity support
- 75% code coverage across all Victory components

### [Alpha 3](https://github.com/FormidableLabs/victory/milestones/Alpha%203)

Expected release: February 2016

- [victory-legend](https://github.com/FormidableLabs/victory/issues/35)
- [victory-area](https://github.com/FormidableLabs/victory/issues/40)
- React native support
- 90% code coverage across all Victory components

==> victory-0.4.2.tgz: package/ROADMAP.md <==
# Victory Release Roadmap

Release schedule for the Victory ecosystem. Subject to change and reprioritization.

## Feature requests

We'd love :heart: to hear what you think we should build! First, please [search for an existing issue](https://github.com/FormidableLabs/victory/issues) with your feature request, and `+1` it. If nobody has suggested it yet, please [create a new issue](https://github.com/FormidableLabs/victory/issues/new?labels=enhancement)!

## Releases

### [Alpha](https://github.com/FormidableLabs/victory/milestones/Alpha)

Released: December 2015 ([`v0.1.0`](https://github.com/FormidableLabs/victory/releases/tag/v0.1.0))

- [victory-animation](https://github.com/FormidableLabs/victory-animation)
- [victory-axis](https://github.com/FormidableLabs/victory-axis)
- [victory-bar](https://github.com/FormidableLabs/victory-bar)
- [victory-chart](https://github.com/FormidableLabs/victory-chart)
- [victory-label](https://github.com/FormidableLabs/victory-label)
- [victory-line](https://github.com/FormidableLabs/victory-line)
- [victory-pie](https://github.com/FormidableLabs/victory-pie)
- [victory-scatter](https://github.com/FormidableLabs/victory-scatter)
- Basic code coverage across all Victory components (#37)

### [Alpha 2](https://github.com/FormidableLabs/victory/milestones/Alpha%202)
Expected release: End of February 2016
- Code reorganization and infrastructure improvements
- [Perf improvements](https://github.com/FormidableLabs/victory/issues/141)
- [Enhancements for victory-label](https://github.com/FormidableLabs/victory-label/issues/35)
- [victory-area](https://github.com/FormidableLabs/victory/issues/40)
- [Support data accessor functions](https://github.com/FormidableLabs/victory/issues/84)
- Basic interactivity support via an event object
- [Support for custom data and label components](https://github.com/FormidableLabs/victory-chart/issues/100)
- 75% code coverage across all Victory components

### [Alpha 3](https://github.com/FormidableLabs/victory/milestones/Alpha%203)
Expected release: End of March 2016
- [victory-tooltip](https://github.com/FormidableLabs/victory/issues/83)
- [victory-legend](https://github.com/FormidableLabs/victory/issues/35)
- Interactivity support with data callbacks
- Support for inverted axes in all chart types
- 90% code coverage across all Victory components
